@@ -26,12 +26,13 @@ from botocore.exceptions import (
 )
 
 LOG = logging.getLogger(__name__)
-DEFAULT_URI_TEMPLATE = '{service}.{region}.{dnsSuffix}' # noqa
+DEFAULT_URI_TEMPLATE = '{service}.{region}.{dnsSuffix}'  # noqa
 DEFAULT_SERVICE_DATA = {'endpoints': {}}
 
 
-class BaseEndpointResolver(object):
+class BaseEndpointResolver:
     """Resolves regions and endpoints. Must be subclassed."""
+
     def construct_endpoint(self, service_name, region_name=None):
         """Resolves an endpoint for a service and region combination.
 
@@ -68,8 +69,9 @@ class BaseEndpointResolver(object):
         """
         raise NotImplementedError
 
-    def get_available_endpoints(self, service_name, partition_name='aws',
-                                allow_non_regional=False):
+    def get_available_endpoints(
+        self, service_name, partition_name='aws', allow_non_regional=False
+    ):
         """Lists the endpoint names of a particular partition.
 
         :type service_name: string
@@ -117,9 +119,13 @@ class EndpointResolver(BaseEndpointResolver):
             result.append(partition['partition'])
         return result
 
-    def get_available_endpoints(self, service_name, partition_name='aws',
-                                allow_non_regional=False,
-                                endpoint_variant_tags=None):
+    def get_available_endpoints(
+        self,
+        service_name,
+        partition_name='aws',
+        allow_non_regional=False,
+        endpoint_variant_tags=None,
+    ):
         result = []
         for partition in self._endpoint_data['partitions']:
             if partition['partition'] != partition_name:
@@ -133,8 +139,8 @@ class EndpointResolver(BaseEndpointResolver):
                 # Only regional endpoints can be modeled with variants
                 if endpoint_variant_tags and is_regional_endpoint:
                     variant_data = self._retrieve_variant_data(
-                        service_endpoints[endpoint_name],
-                        endpoint_variant_tags)
+                        service_endpoints[endpoint_name], endpoint_variant_tags
+                    )
                     if variant_data:
                         result.append(endpoint_name)
                 elif allow_non_regional or is_regional_endpoint:
@@ -142,15 +148,14 @@ class EndpointResolver(BaseEndpointResolver):
         return result
 
     def get_partition_dns_suffix(
-        self,
-        partition_name,
-        endpoint_variant_tags=None
+        self, partition_name, endpoint_variant_tags=None
     ):
         for partition in self._endpoint_data['partitions']:
             if partition['partition'] == partition_name:
                 if endpoint_variant_tags:
                     variant = self._retrieve_variant_data(
-                        partition.get('defaults'), endpoint_variant_tags)
+                        partition.get('defaults'), endpoint_variant_tags
+                    )
                     if variant and 'dnsSuffix' in variant:
                         return variant['dnsSuffix']
                 else:
@@ -163,7 +168,7 @@ class EndpointResolver(BaseEndpointResolver):
         region_name=None,
         partition_name=None,
         use_dualstack_endpoint=False,
-        use_fips_endpoint=False
+        use_fips_endpoint=False,
     ):
         if (
             service_name == 's3'
@@ -180,9 +185,12 @@ class EndpointResolver(BaseEndpointResolver):
 
             if valid_partition is not None:
                 result = self._endpoint_for_partition(
-                    valid_partition, service_name,
-                    region_name, use_dualstack_endpoint, use_fips_endpoint,
-                    True
+                    valid_partition,
+                    service_name,
+                    region_name,
+                    use_dualstack_endpoint,
+                    use_fips_endpoint,
+                    True,
                 )
                 return result
             return None
@@ -190,12 +198,16 @@ class EndpointResolver(BaseEndpointResolver):
         # Iterate over each partition until a match is found.
         for partition in self._endpoint_data['partitions']:
             if use_dualstack_endpoint and (
-                    partition['partition'] in
-                    self._UNSUPPORTED_DUALSTACK_PARTITIONS):
+                partition['partition']
+                in self._UNSUPPORTED_DUALSTACK_PARTITIONS
+            ):
                 continue
             result = self._endpoint_for_partition(
-                partition, service_name, region_name, use_dualstack_endpoint,
-                use_fips_endpoint
+                partition,
+                service_name,
+                region_name,
+                use_dualstack_endpoint,
+                use_fips_endpoint,
             )
             if result:
                 return result
@@ -206,22 +218,33 @@ class EndpointResolver(BaseEndpointResolver):
                 return partition['partition']
         raise UnknownRegionError(
             region_name=region_name,
-            error_msg='No partition found for provided region_name.'
+            error_msg='No partition found for provided region_name.',
         )
 
-    def _endpoint_for_partition(self, partition, service_name, region_name,
-                                use_dualstack_endpoint, use_fips_endpoint,
-                                force_partition=False):
+    def _endpoint_for_partition(
+        self,
+        partition,
+        service_name,
+        region_name,
+        use_dualstack_endpoint,
+        use_fips_endpoint,
+        force_partition=False,
+    ):
         partition_name = partition["partition"]
-        if (use_dualstack_endpoint and
-                partition_name in self._UNSUPPORTED_DUALSTACK_PARTITIONS):
-            error_msg = ("Dualstack endpoints are currently not supported"
-                         " for %s partition" % partition_name)
+        if (
+            use_dualstack_endpoint
+            and partition_name in self._UNSUPPORTED_DUALSTACK_PARTITIONS
+        ):
+            error_msg = (
+                "Dualstack endpoints are currently not supported"
+                " for %s partition" % partition_name
+            )
             raise EndpointVariantError(tags=['dualstack'], error_msg=error_msg)
 
         # Get the service from the partition, or an empty template.
         service_data = partition['services'].get(
-            service_name, DEFAULT_SERVICE_DATA)
+            service_name, DEFAULT_SERVICE_DATA
+        )
         # Use the partition endpoint if no region is supplied.
         if region_name is None:
             if 'partitionEndpoint' in service_data:
@@ -248,12 +271,19 @@ class EndpointResolver(BaseEndpointResolver):
             partition_endpoint = service_data.get('partitionEndpoint')
             is_regionalized = service_data.get('isRegionalized', True)
             if partition_endpoint and not is_regionalized:
-                LOG.debug('Using partition endpoint for %s, %s: %s',
-                          service_name, region_name, partition_endpoint)
+                LOG.debug(
+                    'Using partition endpoint for %s, %s: %s',
+                    service_name,
+                    region_name,
+                    partition_endpoint,
+                )
                 resolve_kwargs['endpoint_name'] = partition_endpoint
                 return self._resolve(**resolve_kwargs)
-            LOG.debug('Creating a regex based endpoint for %s, %s',
-                      service_name, region_name)
+            LOG.debug(
+                'Creating a regex based endpoint for %s, %s',
+                service_name,
+                region_name,
+            )
             return self._resolve(**resolve_kwargs)
 
     def _region_match(self, partition, region_name):
@@ -278,40 +308,48 @@ class EndpointResolver(BaseEndpointResolver):
             tags.append('fips')
         return tags
 
-    def _resolve_variant(self, tags, endpoint_data, service_defaults,
-                         partition_defaults):
+    def _resolve_variant(
+        self, tags, endpoint_data, service_defaults, partition_defaults
+    ):
         result = {}
-        for variants in [endpoint_data, service_defaults,
-                         partition_defaults]:
+        for variants in [endpoint_data, service_defaults, partition_defaults]:
             variant = self._retrieve_variant_data(variants, tags)
             if variant:
                 self._merge_keys(variant, result)
         return result
 
-    def _resolve(self, partition, service_name, service_data, endpoint_name,
-                 use_dualstack_endpoint, use_fips_endpoint):
-        endpoint_data = service_data.get('endpoints', {}).get(endpoint_name, {})
+    def _resolve(
+        self,
+        partition,
+        service_name,
+        service_data,
+        endpoint_name,
+        use_dualstack_endpoint,
+        use_fips_endpoint,
+    ):
+        endpoint_data = service_data.get('endpoints', {}).get(
+            endpoint_name, {}
+        )
 
         if endpoint_data.get('deprecated'):
             LOG.warning(
-                'Client is configured with the deprecated endpoint: %s' % (
-                    endpoint_name
-                )
+                'Client is configured with the deprecated endpoint: %s'
+                % (endpoint_name)
             )
 
         service_defaults = service_data.get('defaults', {})
         partition_defaults = partition.get('defaults', {})
-        tags = self._create_tag_list(use_dualstack_endpoint,
-                                     use_fips_endpoint)
+        tags = self._create_tag_list(use_dualstack_endpoint, use_fips_endpoint)
 
         if tags:
-            result = self._resolve_variant(tags, endpoint_data,
-                                           service_defaults,
-                                           partition_defaults)
+            result = self._resolve_variant(
+                tags, endpoint_data, service_defaults, partition_defaults
+            )
             if result == {}:
-                error_msg = ("Endpoint does not exist for %s in region %s" % (
-                    service_name, endpoint_name
-                ))
+                error_msg = (
+                    f"Endpoint does not exist for {service_name} "
+                    f"in region {endpoint_name}"
+                )
                 raise EndpointVariantError(tags=tags, error_msg=error_msg)
             self._merge_keys(endpoint_data, result)
         else:
@@ -329,13 +367,20 @@ class EndpointResolver(BaseEndpointResolver):
         self._merge_keys(partition_defaults, result)
 
         result['hostname'] = self._expand_template(
-            partition, result['hostname'], service_name, endpoint_name,
-            result['dnsSuffix']
+            partition,
+            result['hostname'],
+            service_name,
+            endpoint_name,
+            result['dnsSuffix'],
         )
         if 'sslCommonName' in result:
             result['sslCommonName'] = self._expand_template(
-                partition, result['sslCommonName'], service_name,
-                endpoint_name, result['dnsSuffix'])
+                partition,
+                result['sslCommonName'],
+                service_name,
+                endpoint_name,
+                result['dnsSuffix'],
+            )
 
         return result
 
@@ -344,8 +389,9 @@ class EndpointResolver(BaseEndpointResolver):
             if key not in result:
                 result[key] = from_data[key]
 
-    def _expand_template(self, partition, template, service_name,
-                         endpoint_name, dnsSuffix):
+    def _expand_template(
+        self, partition, template, service_name, endpoint_name, dnsSuffix
+    ):
         return template.format(
-            service=service_name, region=endpoint_name,
-            dnsSuffix=dnsSuffix)
+            service=service_name, region=endpoint_name, dnsSuffix=dnsSuffix
+        )
